@@ -1,6 +1,6 @@
-#!/usr/bin/env python2
-# Gufw 15.10.0 - http://gufw.org
-# Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
+#!/usr/bin/env python3
+# Gufw 17.04.0 - http://gufw.org
+# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,12 +16,13 @@
 # along with Gufw; if not, see http://www.gnu.org/licenses for more
 # information.
 
-from controller import Controller 
-from instance   import Instance
-from view.gufw  import Gufw
+from gufw.controller import Controller 
+from gufw.instance   import Instance
+from gufw.view.gufw  import Gufw
 
 
 if __name__ == '__main__':
+    
     app_instance = Instance()
     
     controler = Controller()
